@@ -1089,10 +1089,13 @@ class TestAsNumberObjectProxy(unittest.TestCase):
         self.assertEqual(pow(three, 2), pow(3, 2))
 
         # Only PyPy implements __rpow__ for ternary pow().
+        # Note: No longer test for this as pypy 3.9+ seems
+        # to have been updated to not support ternary pow()
+        # in same way.
 
-        if is_pypy:
-            self.assertEqual(pow(three, two, 2), pow(3, 2, 2))
-            self.assertEqual(pow(3, two, 2), pow(3, 2, 2))
+        # if is_pypy:
+        #     self.assertEqual(pow(three, two, 2), pow(3, 2, 2))
+        #     self.assertEqual(pow(3, two, 2), pow(3, 2, 2))
 
         self.assertEqual(pow(three, 2, 2), pow(3, 2, 2))
 
@@ -1580,6 +1583,13 @@ class TestObjectRepresentationObjectProxy(unittest.TestCase):
 
         self.assertNotEqual(repr(value).find('ObjectProxy at'), -1)
 
+    def test_format(self):
+        value = 1
+
+        proxy = wrapt.ObjectProxy(1)
+
+        self.assertEqual("{:0>3}".format(proxy), "{:0>3}".format(value))
+
 class TestDerivedClassCreation(unittest.TestCase):
 
     def test_derived_new(self):
@@ -1842,14 +1852,16 @@ class SpecialMethods(unittest.TestCase):
         proxy = wrapt.ObjectProxy(instance)
 
         self.assertEqual(round(instance), round(proxy))
-
+        self.assertEqual(round(instance, 3), round(proxy, 3))
+        self.assertEqual(round(instance, ndigits=3), round(proxy, ndigits=3))
+        
 class TestArgumentUnpacking(unittest.TestCase):
 
     def test_self_keyword_argument_on_dict(self):
         # A dict when given self as keyword argument uses it to create item in
         # the dict and no attempt is made to use a positional argument.
 
-        d = wrapt.wrappers.CallableObjectProxy(dict)(self='self')
+        d = wrapt.CallableObjectProxy(dict)(self='self')
 
         self.assertEqual(d, dict(self='self'))
 
@@ -1864,7 +1876,7 @@ class TestArgumentUnpacking(unittest.TestCase):
         self.assertEqual(o._args, ('arg1',))
         self.assertEqual(o._kwargs, {})
 
-        o = wrapt.wrappers.CallableObjectProxy(Object)('arg1')
+        o = wrapt.CallableObjectProxy(Object)('arg1')
 
         self.assertEqual(o._args, ('arg1',))
         self.assertEqual(o._kwargs, {})
@@ -1881,7 +1893,7 @@ class TestArgumentUnpacking(unittest.TestCase):
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
         with self.assertRaises(TypeError) as e:
-            wrapt.wrappers.CallableObjectProxy(Object)(self='self')
+            wrapt.CallableObjectProxy(Object)(self='self')
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
@@ -1897,7 +1909,7 @@ class TestArgumentUnpacking(unittest.TestCase):
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
         with self.assertRaises(TypeError) as e:
-            wrapt.wrappers.CallableObjectProxy(Object)(arg1='arg1', self='self')
+            wrapt.CallableObjectProxy(Object)(arg1='arg1', self='self')
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
@@ -1912,7 +1924,7 @@ class TestArgumentUnpacking(unittest.TestCase):
         self.assertEqual(o._args, ())
         self.assertEqual(o._kwargs, dict(self="self"))
 
-        o = wrapt.wrappers.CallableObjectProxy(Object)(self='self')
+        o = wrapt.CallableObjectProxy(Object)(self='self')
 
         self.assertEqual(o._args, ())
         self.assertEqual(o._kwargs, dict(self="self"))
@@ -1930,7 +1942,7 @@ class TestArgumentUnpacking(unittest.TestCase):
         self.assertEqual(o._kwargs, {})
         self.assertEqual(o._self, 'self')
 
-        o = wrapt.wrappers.CallableObjectProxy(Object)(self='self')
+        o = wrapt.CallableObjectProxy(Object)(self='self')
 
         self.assertEqual(o._args, ())
         self.assertEqual(o._kwargs, {})
@@ -1949,7 +1961,7 @@ class TestArgumentUnpacking(unittest.TestCase):
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument '_self'.*", str(e.exception)), None)
 
         with self.assertRaises(TypeError) as e:
-            wrapt.wrappers.CallableObjectProxy(Object)(_self='self')
+            wrapt.CallableObjectProxy(Object)(_self='self')
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument '_self'.*", str(e.exception)), None)
 
@@ -1959,7 +1971,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
         # A dict when given self as keyword argument uses it to create item in
         # the dict and no attempt is made to use a positional argument.
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(dict, arg1='arg1')
+        wrapper = wrapt.PartialCallableObjectProxy(dict, arg1='arg1')
 
         d = wrapper(self='self')
 
@@ -1969,7 +1981,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
         # A dict when given self as keyword argument uses it to create item in
         # the dict and no attempt is made to use a positional argument.
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(dict, self='self')
+        wrapper = wrapt.PartialCallableObjectProxy(dict, self='self')
 
         d = wrapper(arg1='arg1')
 
@@ -1986,7 +1998,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
         self.assertEqual(o._args, ('arg1',))
         self.assertEqual(o._kwargs, {})
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object, 'arg1')
+        wrapper = wrapt.PartialCallableObjectProxy(Object, 'arg1')
 
         o = wrapper()
 
@@ -2004,7 +2016,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
         self.assertEqual(o._args, ('arg1',))
         self.assertEqual(o._kwargs, {})
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object)
+        wrapper = wrapt.PartialCallableObjectProxy(Object)
 
         o = wrapper('arg1')
 
@@ -2022,7 +2034,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object, self='self')
+        wrapper = wrapt.PartialCallableObjectProxy(Object, self='self')
 
         with self.assertRaises(TypeError) as e:
             o = wrapper()
@@ -2040,7 +2052,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object)
+        wrapper = wrapt.PartialCallableObjectProxy(Object)
 
         with self.assertRaises(TypeError) as e:
             o = wrapper(self='self')
@@ -2058,7 +2070,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object, arg1='arg1', self='self')
+        wrapper = wrapt.PartialCallableObjectProxy(Object, arg1='arg1', self='self')
 
         with self.assertRaises(TypeError) as e:
             o = wrapper()
@@ -2076,7 +2088,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object)
+        wrapper = wrapt.PartialCallableObjectProxy(Object)
 
         with self.assertRaises(TypeError) as e:
             o = wrapper(arg1='arg1', self='self')
@@ -2094,7 +2106,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
         self.assertEqual(o._args, ())
         self.assertEqual(o._kwargs, dict(self="self"))
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object, self='self')
+        wrapper = wrapt.PartialCallableObjectProxy(Object, self='self')
 
         o = wrapper()
 
@@ -2112,7 +2124,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
         self.assertEqual(o._args, ())
         self.assertEqual(o._kwargs, dict(self="self"))
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object)
+        wrapper = wrapt.PartialCallableObjectProxy(Object)
 
         o = wrapper(self='self')
 
@@ -2132,7 +2144,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
         self.assertEqual(o._kwargs, {})
         self.assertEqual(o._self, 'self')
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object, self='self')
+        wrapper = wrapt.PartialCallableObjectProxy(Object, self='self')
 
         o = wrapper()
 
@@ -2153,7 +2165,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
         self.assertEqual(o._kwargs, {})
         self.assertEqual(o._self, 'self')
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object)
+        wrapper = wrapt.PartialCallableObjectProxy(Object)
 
         o = wrapper(self='self')
 
@@ -2173,7 +2185,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument '_self'.*", str(e.exception)), None)
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object, _self='self')
+        wrapper = wrapt.PartialCallableObjectProxy(Object, _self='self')
 
         with self.assertRaises(TypeError) as e:
             o = wrapper()
@@ -2192,7 +2204,7 @@ class TestArgumentUnpackingPartial(unittest.TestCase):
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument '_self'.*", str(e.exception)), None)
 
-        wrapper = wrapt.wrappers.PartialCallableObjectProxy(Object)
+        wrapper = wrapt.PartialCallableObjectProxy(Object)
 
         with self.assertRaises(TypeError) as e:
             o = wrapper(_self='self')
@@ -2208,7 +2220,7 @@ class TestArgumentUnpackingWrapperBase(unittest.TestCase):
         def wrapper(wrapped, instance, args, kwargs):
             return wrapped(*args, **kwargs)
 
-        d = wrapt.wrappers.FunctionWrapper(dict, wrapper)(self='self')
+        d = wrapt.FunctionWrapper(dict, wrapper)(self='self')
 
         self.assertEqual(d, dict(self='self'))
 
@@ -2226,7 +2238,7 @@ class TestArgumentUnpackingWrapperBase(unittest.TestCase):
         self.assertEqual(o._args, ('arg1',))
         self.assertEqual(o._kwargs, {})
 
-        o = wrapt.wrappers.FunctionWrapper(Object, wrapper)('arg1')
+        o = wrapt.FunctionWrapper(Object, wrapper)('arg1')
 
         self.assertEqual(o._args, ('arg1',))
         self.assertEqual(o._kwargs, {})
@@ -2246,7 +2258,7 @@ class TestArgumentUnpackingWrapperBase(unittest.TestCase):
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
         with self.assertRaises(TypeError) as e:
-            wrapt.wrappers.FunctionWrapper(Object, wrapper)(self='self')
+            wrapt.FunctionWrapper(Object, wrapper)(self='self')
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
@@ -2265,7 +2277,7 @@ class TestArgumentUnpackingWrapperBase(unittest.TestCase):
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
         with self.assertRaises(TypeError) as e:
-            wrapt.wrappers.FunctionWrapper(Object, wrapper)(arg1='arg1', self='self')
+            wrapt.FunctionWrapper(Object, wrapper)(arg1='arg1', self='self')
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument 'self'.*", str(e.exception)), None)
 
@@ -2283,7 +2295,7 @@ class TestArgumentUnpackingWrapperBase(unittest.TestCase):
         self.assertEqual(o._args, ())
         self.assertEqual(o._kwargs, dict(self="self"))
 
-        o = wrapt.wrappers.FunctionWrapper(Object, wrapper)(self='self')
+        o = wrapt.FunctionWrapper(Object, wrapper)(self='self')
 
         self.assertEqual(o._args, ())
         self.assertEqual(o._kwargs, dict(self="self"))
@@ -2304,7 +2316,7 @@ class TestArgumentUnpackingWrapperBase(unittest.TestCase):
         self.assertEqual(o._kwargs, {})
         self.assertEqual(o._self, 'self')
 
-        o = wrapt.wrappers.FunctionWrapper(Object, wrapper)(self='self')
+        o = wrapt.FunctionWrapper(Object, wrapper)(self='self')
 
         self.assertEqual(o._args, ())
         self.assertEqual(o._kwargs, {})
@@ -2326,7 +2338,7 @@ class TestArgumentUnpackingWrapperBase(unittest.TestCase):
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument '_self'.*", str(e.exception)), None)
 
         with self.assertRaises(TypeError) as e:
-            wrapt.wrappers.FunctionWrapper(Object, wrapper)(_self='self')
+            wrapt.FunctionWrapper(Object, wrapper)(_self='self')
 
         self.assertNotEqual(re.match(".*got multiple values for (keyword )?argument '_self'.*", str(e.exception)), None)
 
@@ -2341,7 +2353,7 @@ class TestArgumentUnpackingBoundFunctionWrapper(unittest.TestCase):
             def function(cls, self, *args, **kwargs):
                 return self, args, kwargs
 
-            function = wrapt.wrappers.FunctionWrapper(function, wrapper)
+            function = wrapt.FunctionWrapper(function, wrapper)
 
         result = Object().function(self='self')
 
@@ -2355,7 +2367,7 @@ class TestArgumentUnpackingBoundFunctionWrapper(unittest.TestCase):
             def function(_self, self, *args, **kwargs):
                 return self, args, kwargs
 
-            function = wrapt.wrappers.FunctionWrapper(function, wrapper)
+            function = wrapt.FunctionWrapper(function, wrapper)
 
         result = Object().function(self='self')
 
@@ -2417,5 +2429,23 @@ class TestArgumentUnpackingDecorator(unittest.TestCase):
 
         self.assertEqual(result, ('self', (), dict(arg1='arg1')))
 
+class TestOverridingSpecialAttributes(unittest.TestCase):
+
+    def test_overriding_class_attribute(self):
+        class Object1: pass
+        class Object2(Object1): pass
+
+        o1 = Object1()
+
+        self.assertEqual(o1.__class__, type(o1))
+
+        o2 = Object2()
+
+        self.assertEqual(o2.__class__, type(o2))
+
+        o2.__class__ = type(o1)
+
+        self.assertEqual(o2.__class__, type(o1))
+
 if __name__ == '__main__':
     unittest.main()
