@@ -145,6 +145,7 @@ class TestWeakFunctionProxy(unittest.TestCase):
 
         self.assertEqual(proxy(1, 2), (1, 2))
 
+        Class.function = None
         Class = None
         gc.collect()
 
@@ -166,6 +167,7 @@ class TestWeakFunctionProxy(unittest.TestCase):
 
         self.assertEqual(proxy(1, 2), (1, 2))
 
+        Class.function = None
         Class = None
         gc.collect()
 
@@ -196,7 +198,7 @@ class TestArgumentUnpackingWeakFunctionProxy(unittest.TestCase):
         def function(self, *args, **kwargs):
             return self, args, kwargs
 
-        proxy = wrapt.wrappers.WeakFunctionProxy(function)
+        proxy = wrapt.WeakFunctionProxy(function)
 
         self.assertEqual(proxy(self='self', arg1='arg1'), ('self', (), dict(arg1='arg1')))
 
